Official Telnyx Bindings for Python
===================================

A Python library for Telnyx's API.


Setup
-----

Install this package by using `pip`:

    $ pip install telnyx


Setting up a Telnyx Account
---------------------------

Sign up for Telnyx at https://portal.telnyx.com


Using the Telnyx API
--------------------

Documentation for the python bindings can be found alongside Telnyx's other bindings here:

- https://developers.telnyx.com
- https://developers.telnyx.com/clients/python
